@@ -13,10 +13,10 @@
 ** is not included in the SQLite library.  It is used for automated
 ** testing of the SQLite library.
 **
-** $Id: test2.c,v 1.16 2004/02/10 01:54:28 drh Exp $
+** $Id: test2.c,v 1.30 2005/05/27 09:41:13 danielk1977 Exp $
 */
-#include "os.h"
 #include "sqliteInt.h"
+#include "os.h"
 #include "pager.h"
 #include "tcl.h"
 #include <stdlib.h>
@@ -55,6 +55,11 @@ static char *errorName(int rc){
   return zName;
 }
 
+/*
+** Page size and reserved size used for testing.
+*/
+static int test_pagesize = 1024;
+
 /*
 ** Usage:   pager_open FILENAME N-PAGE
 **
@@ -76,12 +81,14 @@ static int pager_open(
     return TCL_ERROR;
   }
   if( Tcl_GetInt(interp, argv[2], &nPage) ) return TCL_ERROR;
-  rc = sqlitepager_open(&pPager, argv[1], nPage, 0, 1);
+  rc = sqlite3pager_open(&pPager, argv[1], 0, 0);
   if( rc!=SQLITE_OK ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
   }
-  sprintf(zBuf,"0x%x",(int)pPager);
+  sqlite3pager_set_cachesize(pPager, nPage);
+  sqlite3pager_set_pagesize(pPager, test_pagesize);
+  sqlite3_snprintf(sizeof(zBuf),zBuf,"%p",pPager);
   Tcl_AppendResult(interp, zBuf, 0);
   return TCL_OK;
 }
@@ -104,8 +111,8 @@ static int pager_close(
        " ID\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPager) ) return TCL_ERROR;
-  rc = sqlitepager_close(pPager);
+  pPager = sqlite3TextToPtr(argv[1]);
+  rc = sqlite3pager_close(pPager);
   if( rc!=SQLITE_OK ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
@@ -131,8 +138,8 @@ static int pager_rollback(
        " ID\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPager) ) return TCL_ERROR;
-  rc = sqlitepager_rollback(pPager);
+  pPager = sqlite3TextToPtr(argv[1]);
+  rc = sqlite3pager_rollback(pPager);
   if( rc!=SQLITE_OK ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
@@ -158,8 +165,8 @@ static int pager_commit(
        " ID\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPager) ) return TCL_ERROR;
-  rc = sqlitepager_commit(pPager);
+  pPager = sqlite3TextToPtr(argv[1]);
+  rc = sqlite3pager_commit(pPager);
   if( rc!=SQLITE_OK ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
@@ -168,11 +175,11 @@ static int pager_commit(
 }
 
 /*
-** Usage:   pager_ckpt_begin ID
+** Usage:   pager_stmt_begin ID
 **
 ** Start a new checkpoint.
 */
-static int pager_ckpt_begin(
+static int pager_stmt_begin(
   void *NotUsed,
   Tcl_Interp *interp,    /* The TCL interpreter that invoked this command */
   int argc,              /* Number of arguments */
@@ -185,8 +192,8 @@ static int pager_ckpt_begin(
        " ID\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPager) ) return TCL_ERROR;
-  rc = sqlitepager_ckpt_begin(pPager);
+  pPager = sqlite3TextToPtr(argv[1]);
+  rc = sqlite3pager_stmt_begin(pPager);
   if( rc!=SQLITE_OK ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
@@ -195,11 +202,11 @@ static int pager_ckpt_begin(
 }
 
 /*
-** Usage:   pager_ckpt_rollback ID
+** Usage:   pager_stmt_rollback ID
 **
 ** Rollback changes to a checkpoint
 */
-static int pager_ckpt_rollback(
+static int pager_stmt_rollback(
   void *NotUsed,
   Tcl_Interp *interp,    /* The TCL interpreter that invoked this command */
   int argc,              /* Number of arguments */
@@ -212,8 +219,8 @@ static int pager_ckpt_rollback(
        " ID\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPager) ) return TCL_ERROR;
-  rc = sqlitepager_ckpt_rollback(pPager);
+  pPager = sqlite3TextToPtr(argv[1]);
+  rc = sqlite3pager_stmt_rollback(pPager);
   if( rc!=SQLITE_OK ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
@@ -222,11 +229,11 @@ static int pager_ckpt_rollback(
 }
 
 /*
-** Usage:   pager_ckpt_commit ID
+** Usage:   pager_stmt_commit ID
 **
 ** Commit changes to a checkpoint
 */
-static int pager_ckpt_commit(
+static int pager_stmt_commit(
   void *NotUsed,
   Tcl_Interp *interp,    /* The TCL interpreter that invoked this command */
   int argc,              /* Number of arguments */
@@ -239,8 +246,8 @@ static int pager_ckpt_commit(
        " ID\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPager) ) return TCL_ERROR;
-  rc = sqlitepager_ckpt_commit(pPager);
+  pPager = sqlite3TextToPtr(argv[1]);
+  rc = sqlite3pager_stmt_commit(pPager);
   if( rc!=SQLITE_OK ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
@@ -266,8 +273,8 @@ static int pager_stats(
        " ID\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPager) ) return TCL_ERROR;
-  a = sqlitepager_stats(pPager);
+  pPager = sqlite3TextToPtr(argv[1]);
+  a = sqlite3pager_stats(pPager);
   for(i=0; i<9; i++){
     static char *zName[] = {
       "ref", "page", "max", "size", "state", "err",
@@ -275,7 +282,7 @@ static int pager_stats(
     };
     char zBuf[100];
     Tcl_AppendElement(interp, zName[i]);
-    sprintf(zBuf,"%d",a[i]);
+    sqlite3_snprintf(sizeof(zBuf),zBuf,"%d",a[i]);
     Tcl_AppendElement(interp, zBuf);
   }
   return TCL_OK;
@@ -299,8 +306,8 @@ static int pager_pagecount(
        " ID\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPager) ) return TCL_ERROR;
-  sprintf(zBuf,"%d",sqlitepager_pagecount(pPager));
+  pPager = sqlite3TextToPtr(argv[1]);
+  sqlite3_snprintf(sizeof(zBuf),zBuf,"%d",sqlite3pager_pagecount(pPager));
   Tcl_AppendResult(interp, zBuf, 0);
   return TCL_OK;
 }
@@ -326,14 +333,14 @@ static int page_get(
        " ID PGNO\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPager) ) return TCL_ERROR;
+  pPager = sqlite3TextToPtr(argv[1]);
   if( Tcl_GetInt(interp, argv[2], &pgno) ) return TCL_ERROR;
-  rc = sqlitepager_get(pPager, pgno, &pPage);
+  rc = sqlite3pager_get(pPager, pgno, &pPage);
   if( rc!=SQLITE_OK ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
   }
-  sprintf(zBuf,"0x%x",(int)pPage);
+  sqlite3_snprintf(sizeof(zBuf),zBuf,"%p",pPage);
   Tcl_AppendResult(interp, zBuf, 0);
   return TCL_OK;
 }
@@ -359,16 +366,44 @@ static int page_lookup(
        " ID PGNO\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPager) ) return TCL_ERROR;
+  pPager = sqlite3TextToPtr(argv[1]);
   if( Tcl_GetInt(interp, argv[2], &pgno) ) return TCL_ERROR;
-  pPage = sqlitepager_lookup(pPager, pgno);
+  pPage = sqlite3pager_lookup(pPager, pgno);
   if( pPage ){
-    sprintf(zBuf,"0x%x",(int)pPage);
+    sqlite3_snprintf(sizeof(zBuf),zBuf,"%p",pPage);
     Tcl_AppendResult(interp, zBuf, 0);
   }
   return TCL_OK;
 }
 
+/*
+** Usage:   pager_truncate ID PGNO
+*/
+static int pager_truncate(
+  void *NotUsed,
+  Tcl_Interp *interp,    /* The TCL interpreter that invoked this command */
+  int argc,              /* Number of arguments */
+  const char **argv      /* Text of each argument */
+){
+  Pager *pPager;
+  int rc;
+  int pgno;
+  if( argc!=3 ){
+    Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
+       " ID PGNO\"", 0);
+    return TCL_ERROR;
+  }
+  pPager = sqlite3TextToPtr(argv[1]);
+  if( Tcl_GetInt(interp, argv[2], &pgno) ) return TCL_ERROR;
+  rc = sqlite3pager_truncate(pPager, pgno);
+  if( rc!=SQLITE_OK ){
+    Tcl_AppendResult(interp, errorName(rc), 0);
+    return TCL_ERROR;
+  }
+  return TCL_OK;
+}
+
+
 /*
 ** Usage:   page_unref PAGE
 **
@@ -387,8 +422,8 @@ static int page_unref(
        " PAGE\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPage) ) return TCL_ERROR;
-  rc = sqlitepager_unref(pPage);
+  pPage = sqlite3TextToPtr(argv[1]);
+  rc = sqlite3pager_unref(pPage);
   if( rc!=SQLITE_OK ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
@@ -414,7 +449,7 @@ static int page_read(
        " PAGE\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPage) ) return TCL_ERROR;
+  pPage = sqlite3TextToPtr(argv[1]);
   memcpy(zBuf, pPage, sizeof(zBuf));
   Tcl_AppendResult(interp, zBuf, 0);
   return TCL_OK;
@@ -438,8 +473,8 @@ static int page_number(
        " PAGE\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPage) ) return TCL_ERROR;
-  sprintf(zBuf, "%d", sqlitepager_pagenumber(pPage));
+  pPage = sqlite3TextToPtr(argv[1]);
+  sqlite3_snprintf(sizeof(zBuf), zBuf, "%d", sqlite3pager_pagenumber(pPage));
   Tcl_AppendResult(interp, zBuf, 0);
   return TCL_OK;
 }
@@ -462,17 +497,18 @@ static int page_write(
        " PAGE DATA\"", 0);
     return TCL_ERROR;
   }
-  if( Tcl_GetInt(interp, argv[1], (int*)&pPage) ) return TCL_ERROR;
-  rc = sqlitepager_write(pPage);
+  pPage = sqlite3TextToPtr(argv[1]);
+  rc = sqlite3pager_write(pPage);
   if( rc!=SQLITE_OK ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
   }
-  strncpy((char*)pPage, argv[2], SQLITE_USABLE_SIZE-1);
-  ((char*)pPage)[SQLITE_USABLE_SIZE-1] = 0;
+  strncpy((char*)pPage, argv[2], test_pagesize-1);
+  ((char*)pPage)[test_pagesize-1] = 0;
   return TCL_OK;
 }
 
+#ifndef SQLITE_OMIT_DISKIO
 /*
 ** Usage:   fake_big_file  N  FILENAME
 **
@@ -490,7 +526,7 @@ static int fake_big_file(
 ){
   int rc;
   int n;
-  off_t offset;
+  i64 offset;
   OsFile fd;
   int readOnly = 0;
   if( argc!=3 ){
@@ -499,33 +535,35 @@ static int fake_big_file(
     return TCL_ERROR;
   }
   if( Tcl_GetInt(interp, argv[1], &n) ) return TCL_ERROR;
-  rc = sqliteOsOpenReadWrite(argv[2], &fd, &readOnly);
+  memset(&fd, 0, sizeof(fd));
+  rc = sqlite3OsOpenReadWrite(argv[2], &fd, &readOnly);
   if( rc ){
     Tcl_AppendResult(interp, "open failed: ", errorName(rc), 0);
     return TCL_ERROR;
   }
   offset = n;
   offset *= 1024*1024;
-  rc = sqliteOsSeek(&fd, offset);
+  rc = sqlite3OsSeek(&fd, offset);
   if( rc ){
     Tcl_AppendResult(interp, "seek failed: ", errorName(rc), 0);
     return TCL_ERROR;
   }
-  rc = sqliteOsWrite(&fd, "Hello, World!", 14);
-  sqliteOsClose(&fd);
+  rc = sqlite3OsWrite(&fd, "Hello, World!", 14);
+  sqlite3OsClose(&fd);
   if( rc ){
     Tcl_AppendResult(interp, "write failed: ", errorName(rc), 0);
     return TCL_ERROR;
   }
   return TCL_OK;
 }
+#endif
 
 /*
 ** Register commands with the TCL interpreter.
 */
 int Sqlitetest2_Init(Tcl_Interp *interp){
-  extern int sqlite_io_error_pending;
-  char zBuf[100];
+  extern int sqlite3_io_error_pending;
+  extern int sqlite3_diskfull_pending;
   static struct {
     char *zName;
     Tcl_CmdProc *xProc;
@@ -534,9 +572,9 @@ int Sqlitetest2_Init(Tcl_Interp *interp){
     { "pager_close",             (Tcl_CmdProc*)pager_close         },
     { "pager_commit",            (Tcl_CmdProc*)pager_commit        },
     { "pager_rollback",          (Tcl_CmdProc*)pager_rollback      },
-    { "pager_ckpt_begin",        (Tcl_CmdProc*)pager_ckpt_begin    },
-    { "pager_ckpt_commit",       (Tcl_CmdProc*)pager_ckpt_commit   },
-    { "pager_ckpt_rollback",     (Tcl_CmdProc*)pager_ckpt_rollback },
+    { "pager_stmt_begin",        (Tcl_CmdProc*)pager_stmt_begin    },
+    { "pager_stmt_commit",       (Tcl_CmdProc*)pager_stmt_commit   },
+    { "pager_stmt_rollback",     (Tcl_CmdProc*)pager_stmt_rollback },
     { "pager_stats",             (Tcl_CmdProc*)pager_stats         },
     { "pager_pagecount",         (Tcl_CmdProc*)pager_pagecount     },
     { "page_get",                (Tcl_CmdProc*)page_get            },
@@ -545,23 +583,20 @@ int Sqlitetest2_Init(Tcl_Interp *interp){
     { "page_read",               (Tcl_CmdProc*)page_read           },
     { "page_write",              (Tcl_CmdProc*)page_write          },
     { "page_number",             (Tcl_CmdProc*)page_number         },
+    { "pager_truncate",          (Tcl_CmdProc*)pager_truncate      },
+#ifndef SQLITE_OMIT_DISKIO
     { "fake_big_file",           (Tcl_CmdProc*)fake_big_file       },
+#endif
   };
   int i;
   for(i=0; i<sizeof(aCmd)/sizeof(aCmd[0]); i++){
     Tcl_CreateCommand(interp, aCmd[i].zName, aCmd[i].xProc, 0, 0);
   }
   Tcl_LinkVar(interp, "sqlite_io_error_pending",
-     (char*)&sqlite_io_error_pending, TCL_LINK_INT);
-#ifdef SQLITE_TEST
-  Tcl_LinkVar(interp, "journal_format",
-     (char*)&journal_format, TCL_LINK_INT);
-#endif
-  sprintf(zBuf, "%d", SQLITE_PAGE_SIZE);
-  Tcl_SetVar(interp, "SQLITE_PAGE_SIZE", zBuf, TCL_GLOBAL_ONLY); 
-  sprintf(zBuf, "%d", SQLITE_PAGE_RESERVE);
-  Tcl_SetVar(interp, "SQLITE_PAGE_RESERVE", zBuf, TCL_GLOBAL_ONLY); 
-  sprintf(zBuf, "%d", SQLITE_USABLE_SIZE);
-  Tcl_SetVar(interp, "SQLITE_USABLE_SIZE", zBuf, TCL_GLOBAL_ONLY); 
+     (char*)&sqlite3_io_error_pending, TCL_LINK_INT);
+  Tcl_LinkVar(interp, "sqlite_diskfull_pending",
+     (char*)&sqlite3_diskfull_pending, TCL_LINK_INT);
+  Tcl_LinkVar(interp, "pager_pagesize",
+     (char*)&test_pagesize, TCL_LINK_INT);
   return TCL_OK;
 }
